@@ -1,5 +1,5 @@
 package QBit::Application::Part;
-$QBit::Application::Part::VERSION = '0.012';
+$QBit::Application::Part::VERSION = '0.013';
 use qbit;
 
 use base qw(QBit::Class);
@@ -103,7 +103,7 @@ sub import {
 
     {
         no strict 'refs';
-        foreach my $method (qw(check_rights)) {
+        foreach my $method (qw(check_rights cur_user)) {
             *{"${package}::${method}"} = sub {shift->app->$method(@_)};
         }
     }
